;;; DO NOT MODIFY THIS FILE
(if (featurep 'egg-its-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "egg-its/_pkg.el")

(package-provide 'egg-its :version 1.25 :type 'regular)

;;;***

;;;### (autoloads (kakusuu-input busyu-input) "egg-busyu" "egg-its/egg-busyu.el")

(autoload 'busyu-input "egg-busyu" nil t nil)

(autoload 'kakusuu-input "egg-busyu" nil t nil)

;;;***

;;;### (autoloads (egg-zhuyin-inactivate egg-zhuyin-activate egg-pinyin-inactivate egg-pinyin-activate) "egg-cwnn-leim" "egg-its/egg-cwnn-leim.el")

(autoload 'egg-pinyin-activate "egg-cwnn-leim" nil nil nil)

(autoload 'egg-pinyin-inactivate "egg-cwnn-leim" nil nil nil)

(autoload 'egg-zhuyin-activate "egg-cwnn-leim" nil nil nil)

(autoload 'egg-zhuyin-inactivate "egg-cwnn-leim" nil nil nil)

(when (and (featurep 'mule) (featurep 'wnn)) (register-input-method 'chinese-egg-pinyin "Chinese" 'egg-zhuyin-activate nil "EGG - an interface to the CWnn Chinese conversion program"))

(when (and (featurep 'mule) (featurep 'wnn)) (register-input-method 'chinese-egg-zhuyin "Chinese" 'egg-zhuyin-activate nil "EGG - an interface to the CWnn Chinese conversion program"))

;;;***

;;;### (autoloads (egg-kwnn-inactivate egg-kwnn-activate) "egg-kwnn-leim" "egg-its/egg-kwnn-leim.el")

(autoload 'egg-kwnn-activate "egg-kwnn-leim" nil nil nil)

(autoload 'egg-kwnn-inactivate "egg-kwnn-leim" nil nil nil)

(when (and (featurep 'mule) (featurep 'wnn)) (register-input-method 'korean-egg "Korean" 'egg-kwnn-activate nil "EGG - an interface to the kWnn Korean conversion program"))

;;;***

;;;### (autoloads (egg-inactivate egg-activate) "egg-leim" "egg-its/egg-leim.el")

(autoload 'egg-activate "egg-leim" nil nil nil)

(autoload 'egg-inactivate "egg-leim" nil nil nil)

(when (and (featurep 'mule) (featurep 'wnn)) (register-input-method 'japanese-egg-wnn "Japanese" 'egg-activate nil "EGG - an interface to the Wnn kana to kanji conversion program"))

;;;***

;;;### (autoloads (egg-sj3-inactivate egg-sj3-activate) "egg-sj3-leim" "egg-its/egg-sj3-leim.el")

(autoload 'egg-sj3-activate "egg-sj3-leim" nil nil nil)

(autoload 'egg-sj3-inactivate "egg-sj3-leim" nil nil nil)

(when (featurep 'wnn) (register-input-method 'japanese-egg-sj3 "Japanese" 'egg-sj3-activate nil "EGG - an interface to the SJ3 kana to kanji conversion program"))

;;;***

(provide 'egg-its-autoloads)
